# -*- coding: utf-8 -*-
from django.db import models


class CommentForPaginateByMaxMixin(models.Model):
    email = models.EmailField()
    content = models.CharField(max_length=200)
    created = models.DateTimeField(auto_now_add=True)

    class Meta:
        ordering = ['id']
